Aspect is a universal grammatical notion relating to the particular status of an action or event. When we speak of an action, we may view it as a process consisting of a series of phases, including the beginning, continuation, repetition, completion, etc. Each of these phases is an aspect which may be selected for emphasis in conversation.

For example, the aspectual emphases of the following two English sentences are different:
1. *I was eating lunch* when he called.
2. *I had already eaten lunch* when he called.
In (1) the progression of the eating process is emphasised, whereas in (2) the completion is.

Regardless of when the action occurred, it may always be characterised with an emphasis on one of its aspects. The following sentences show the progressive aspect appearing in all three tenses in English:
1. *Past*: "What were you doing yesterday when he called?"
2. *Present*: "What are you doing now?"
3. *Future*: "What will you be doing this time tomorrow morning?"
In this case, in English, the progressive aspect is marked with the verb: "were doing", "are doing", "will be doing". 

Chinese, however, doesn't have any way of forming tenses with verbs. If necessary, time markers are used to specify the time context, but the verb is not conjugated:
1. 我**去年**在北京大学学习汉语。
   **Last year**, I studied Chinese at Beijing University. *(past)*
2. 我**现在**在北京大学学习汉语。
   I am **now** studying Chinese at Beijing University. *(present)*
Thus one can consider Mandarin as having no tenses. However, Mandarin does have multiple aspects. 

# Progressive Aspect
#在 #呢 

The progressive aspect marks an ongoing aspect of an action. In Chinese, we may place the verb 在zài before the predicate, and/or the particle 呢ne after it. In forming this pattern, there are three options to choose from - the choice of the three renders almost no difference in meaning, however.
```
(A) 在 + predicate + 呢
(B) 在 + predicate
(C)      predicate + 呢
```
For example:
 1. (A) 我**在**看报**呢**。
    (B) 我**在**看报。
    (C) 我看报**呢**。
    I'm in the midst of reading a newspaper.

> [!warning] Questions
> When forming questions, option (C) is the least stylistically preferred of the three. Just use (A) or (B):
> (A) 你在看报呢吗？
> (B) 你在看报吗？
> "Are you in the process of reading the newspaper?"

## Negation
#没有

When negating a progressive sentence, we need to use 没有 instead of 不, before the verb unit - with or without 在. The final 呢 has to be dropped. 没有 can be shortened to 没 when standing before a verb, but it has to be in the full form in a short answer.
Examples:
1. **Question**
   你在看电视呢吗？
   Are you in the midst of watching TV?
   **Answer**
   没有，我没(有)在看电视。
   Nope, I'm not in the midst of watching TV.
2. **Question**
   早上八点中的时候，你在打电话呢吗？
   Yesterday at 8AM, were you on the phone?
   **Answer**
   没有，我没(有)(在)打电话，我在听新闻呢。
   Nope, I wasn't on the phone - I was listening to the news.
3. **Question**
   他在睡觉呢吗？
   Is he taking a nap?
   **Answer**
   他没(有)(在)睡觉，他在整理房间呢。
   Nope, he isn't taking a nap - he's in the midst of cleaning his room.
在 is only optional is (2) and (3) - where the negative answer is followed by a positive description of what actually took/is taking/will take place.

What about when we want to use 在 to give a location? It can do both at the same time - you *should not* duplicate it. However, it makes sense to use 呢 to make it clear we are employing the progressive aspect:
> 我们在花园里玩儿呢。
> We're in the midst of playing in the garden.

## 正在zhèngzài
#正在 

In English, we can emphasise that there is a disturbance, interception, or interruption like so:
1. I was in the middle of cooking when he dropped in.
2. I was *right* in the middle of cooking when he dropped in.
Sentence (2) is a bit more vivid, and emphasises the interruption.

In Chinese, the equivalent is putting 正zhèng before 在zài when using the progressive aspect:
```
正在 + verb (+ object) + 呢
```

The inclusion of 正 pinpoints an ongoing action to a specific point in time. This roughly translates a bit like "right" in English. The time may be explicitly expressed by a time word (as in the following example (1)), a time clause (as in (2)), or implicitly inferred (as in (3)):
1. 他们现在**正**在上课呢。
   They are in class **right** now.
2. 你昨天来找他的时候，他**正**在洗澡呢。
   When you came to look for him yesterday, he was **right** in the middle of taking a shower.
3. 他们**正**在跳舞呢。
   (At this very moment) They are **right** in the midst of dancing.
In (2) above, the second clause emphasises that the first clause was unfortunately timed. If they were unrelated, we wouldn't use 正. For example:
1. 昨天晚上王太太做饭的时候，李先生在洗衣服。
   Yesterday whilst Mrs. Wang was cooking, Mr. Li was doing his laundry.
2. 昨天晚上你做饭的时候，我正在洗衣服呢。
   Yesterday while you were cooking, I was right in the middle of doing my laundry.
In (1) above, the actions are presented as parallel but unrelated. In (2), it's different - it's more of a "yesterday while you cooked, I was busy with my laundry, so don't blame me for not helping out!".
